# 🧐 Getting Started

The next couple of sections will walk you through getting set up to use odin\_api. It will cover downloading Python and an IDE for you to write code in, setting up an environment variable something that the library needs, all the way through to getting your first lines of code written using the library.
